// @flow

/* Some fields can use the container to more easily add conistent error handling, and other functionality. */

import React from 'react'
import { View, Text } from 'react-native'
// import validate from 'react-final-form-fields-validate'
import styled from 'styled-components/native'

const Tooltip = styled.Text`
  font-size: 12;
  line-height: 18;
  color: gray;
  margin-top: 2;
`

// import SpeechBubble from '../common/SpeechBubble'

type CommonProps = {
  children: React.Element,
  input: Object,
  meta?: Object,
  id?: string,
}

type TextFieldProps = {
  ...CommonProps,
  label: string,
  beforeElement?: any,
  onKeyUp?: () => void,
  containers?: React.Element | string,
}

const classes = {
  label: {
    color: 'black',
    fontSize: '0.75em',
    width: '100%',
  },
  labelUnchecked: {
    padding: '16px 51px',
    border: '1px solid rgb(136, 136, 136)',
  },
  textField: {
    borderBottom: '1px solid #7c8c97',
  },
  textFieldContainer: {
    display: 'flex',
    flexDirection: 'column',
    color: 'black',
  },
  error: {
    fontSize: 12,
    color: 'red',
  },
  defaultContainerStyle: {
    minWidth: '33%',
    padding: '0.5em 0.5em 0 0.5em ',
    height: 69,
    width: '100%',
  },
}

const SwitchBadge = ({ status }) => <View>{status}</View>

const Container = ({
  children,
  containers,
  containerStyle,
  id,
  input,
  label,
  meta,
  meta: { error, touched },
  verification,
  tooltip,
}: CommonProps) => {
  const showError = !!touched && !!error
  const {
    OuterContainer = View,
    LabelContainer = View,
    Label = Text,
    ErrorContainer = View,
    ErrorText = Text,
    FieldContaner = styled.View`
      display: flex;
      flex-direction: row;
      flex-grow: 1;
    `,
  } = containers

  return (
    <OuterContainer meta={meta} id={id}>
      <LabelContainer meta={meta} htmlFor={`Checkbox_${input.name}`}>
        <Label meta={meta}>{label}</Label>
      </LabelContainer>
      <FieldContaner>
        {children.map(child => child)}
        {verification && <SwitchBadge status={verification} />}
      </FieldContaner>
      {tooltip && <Tooltip>{tooltip}</Tooltip>}
      {showError && (
        <ErrorContainer id={`Fields_${name}-error`} style={classes.error}>
          <ErrorText>{error}</ErrorText>
        </ErrorContainer>
      )}
    </OuterContainer>
  )
}

export default Container
